@@ -3,6 +3,7 @@
 from Acquisition import aq_inner
 from imio.smartweb.core.contents import IFolder
 from imio.smartweb.core.interfaces import IViewWithoutLeadImage
+from imio.smartweb.core.utils import get_scale_url
 from imio.smartweb.locales import SmartwebMessageFactory as _
 from plone import api
 from plone.app.content.browser.contents import ContextInfo
@@ -79,6 +80,10 @@ class FolderView(BaseFolderView):
         ]
         return {"results": results, "quick_access": quick_access_brains}
 
+    def get_scale_url(self, item, scale):
+        request = self.request
+        return get_scale_url(item, request, "image", scale)
+
 
 @implementer(IViewWithoutLeadImage)
 class FolderViewWithImages(FolderView):
