@@ -37,7 +37,7 @@ class TestFooter(ImioSmartwebTestCase):
 
     def test_add_footer_to_plonesite(self):
         view = getMultiAdapter((self.portal, self.request), name="footer_settings")
-        self.assertTrue(view.available)
+        self.assertTrue(view.available())
         viewlet = FooterViewlet(self.portal, self.request, None, None)
         viewlet.update()
         self.assertFalse(viewlet.available())
@@ -46,17 +46,17 @@ class TestFooter(ImioSmartwebTestCase):
             contentFilter={"portal_type": "imio.smartweb.Footer"}
         )
         self.assertEqual(len(footers), 1)
-        self.assertFalse(view.available)
+        self.assertFalse(view.available())
         viewlet = FooterViewlet(self.portal, self.request, None, None)
         viewlet.update()
         self.assertTrue(viewlet.available())
         self.assertEqual(viewlet.footer, footers[0])
         api.content.delete(footers[0])
-        self.assertTrue(view.available)
+        self.assertTrue(view.available())
 
     def test_add_footer_to_folder(self):
         view = getMultiAdapter((self.folder, self.request), name="footer_settings")
-        self.assertFalse(view.available)
+        self.assertFalse(view.available())
         view.add_footer()
         footers = self.portal.listFolderContents(
             contentFilter={"portal_type": "imio.smartweb.Footer"}
@@ -67,20 +67,20 @@ class TestFooter(ImioSmartwebTestCase):
         footer_view = getMultiAdapter(
             (self.folder, self.request), name="footer_settings"
         )
-        self.assertFalse(footer_view.available)
+        self.assertFalse(footer_view.available())
         subsite_view = getMultiAdapter(
             (self.folder, self.request), name="subsite_settings"
         )
         subsite_view.enable()
-        self.assertTrue(footer_view.available)
+        self.assertTrue(footer_view.available())
         footer_view.add_footer()
         footers = self.folder.listFolderContents(
             contentFilter={"portal_type": "imio.smartweb.Footer"}
         )
         self.assertEqual(len(footers), 1)
-        self.assertFalse(footer_view.available)
+        self.assertFalse(footer_view.available())
         api.content.delete(footers[0])
-        self.assertTrue(footer_view.available)
+        self.assertTrue(footer_view.available())
 
     def test_add_footer_to_nested_subsite(self):
         nested_folder = api.content.create(
@@ -119,20 +119,20 @@ class TestFooter(ImioSmartwebTestCase):
         footer_view = getMultiAdapter(
             (self.folder, self.request), name="footer_settings"
         )
-        self.assertFalse(footer_view.available)
+        self.assertFalse(footer_view.available())
         minisite_view = getMultiAdapter(
             (self.folder, self.request), name="minisite_settings"
         )
         minisite_view.enable()
-        self.assertTrue(footer_view.available)
+        self.assertTrue(footer_view.available())
         footer_view.add_footer()
         footers = self.folder.listFolderContents(
             contentFilter={"portal_type": "imio.smartweb.Footer"}
         )
         self.assertEqual(len(footers), 1)
-        self.assertFalse(footer_view.available)
+        self.assertFalse(footer_view.available())
         api.content.delete(footers[0])
-        self.assertTrue(footer_view.available)
+        self.assertTrue(footer_view.available())
 
     def test_portal_and_minisite_footers(self):
         view = getMultiAdapter((self.portal, self.request), name="footer_settings")
