@@ -64,30 +64,30 @@ class TestMinisite(ImioSmartwebTestCase):
 
     def test_activation(self):
         view = getMultiAdapter((self.portal, self.request), name="minisite_settings")
-        self.assertFalse(view.available)
+        self.assertFalse(view.available())
 
         view = getMultiAdapter((self.folder, self.request), name="minisite_settings")
-        self.assertTrue(view.available)
-        self.assertFalse(view.enabled)
+        self.assertTrue(view.available())
+        self.assertFalse(view.enabled())
 
         view.enable()
         self.assertTrue(IImioSmartwebMinisite.providedBy(self.folder))
         self.assertTrue(INavigationRoot.providedBy(self.folder))
 
-        self.assertFalse(view.available)
-        self.assertTrue(view.enabled)
+        self.assertFalse(view.available())
+        self.assertTrue(view.enabled())
 
         view.disable()
         self.assertFalse(IImioSmartwebMinisite.providedBy(self.folder))
         self.assertFalse(INavigationRoot.providedBy(self.folder))
-        self.assertTrue(view.available)
-        self.assertFalse(view.enabled)
+        self.assertTrue(view.available())
+        self.assertFalse(view.enabled())
 
         subsite_view = getMultiAdapter(
             (self.folder, self.request), name="subsite_settings"
         )
         subsite_view.enable()
-        self.assertFalse(view.available)
+        self.assertFalse(view.available())
 
         subfolder = api.content.create(
             container=self.folder,
@@ -96,9 +96,9 @@ class TestMinisite(ImioSmartwebTestCase):
             id="subfolder",
         )
         view = getMultiAdapter((subfolder, self.request), name="minisite_settings")
-        self.assertFalse(view.available)
+        self.assertFalse(view.available())
         view.enable()
-        self.assertFalse(view.enabled)
+        self.assertFalse(view.enabled())
 
     def test_minisite_exclude_from_nav(self):
         view = getMultiAdapter((self.folder, self.request), name="minisite_settings")
@@ -223,8 +223,8 @@ class TestMinisite(ImioSmartwebTestCase):
         )
         moved_folder = api.content.move(self.folder, folder2)
         view = getMultiAdapter((moved_folder, self.request), name="minisite_settings")
-        self.assertFalse(view.available)
-        self.assertFalse(view.enabled)
+        self.assertFalse(view.available())
+        self.assertFalse(view.enabled())
         self.assertFalse(IImioSmartwebMinisite.providedBy(moved_folder))
 
     def test_copy_minisite_in_folder(self):
@@ -238,10 +238,27 @@ class TestMinisite(ImioSmartwebTestCase):
         )
         copied_folder = api.content.copy(self.folder, folder2)
         view = getMultiAdapter((copied_folder, self.request), name="minisite_settings")
-        self.assertFalse(view.available)
-        self.assertFalse(view.enabled)
+        self.assertFalse(view.available())
+        self.assertFalse(view.enabled())
         self.assertFalse(IImioSmartwebMinisite.providedBy(copied_folder))
 
+    def test_move_minisite_in_minisite(self):
+        view = getMultiAdapter((self.folder, self.request), name="minisite_settings")
+        view.enable()
+        folder2 = api.content.create(
+            container=self.portal,
+            type="imio.smartweb.Folder",
+            title="Folder2",
+            id="folder2",
+        )
+        view = getMultiAdapter((folder2, self.request), name="minisite_settings")
+        view.enable()
+        moved_folder = api.content.move(self.folder, folder2)
+        view = getMultiAdapter((moved_folder, self.request), name="minisite_settings")
+        self.assertFalse(view.available())
+        self.assertFalse(view.enabled())
+        self.assertFalse(IImioSmartwebMinisite.providedBy(moved_folder))
+
     def test_minisite_in_minisite(self):
         view = getMultiAdapter((self.folder, self.request), name="minisite_settings")
         view.enable()
@@ -254,7 +271,7 @@ class TestMinisite(ImioSmartwebTestCase):
             id="minisite2",
         )
         view = getMultiAdapter((minisite2, self.request), name="minisite_settings")
-        self.assertFalse(view.available)
+        self.assertFalse(view.available())
 
     def test_cannot_enable_minisite_on_subsite(self):
         subsite_view = getMultiAdapter(
@@ -264,10 +281,10 @@ class TestMinisite(ImioSmartwebTestCase):
         minisite_view = getMultiAdapter(
             (self.folder, self.request), name="minisite_settings"
         )
-        self.assertFalse(minisite_view.available)
-        self.assertFalse(minisite_view.enabled)
+        self.assertFalse(minisite_view.available())
+        self.assertFalse(minisite_view.enabled())
         minisite_view.enable()
-        self.assertFalse(minisite_view.enabled)
+        self.assertFalse(minisite_view.enabled())
 
     def test_minisite_viewlet_logo(self):
         viewlet = LogoViewlet(self.folder, self.request, None, None)
@@ -279,7 +296,9 @@ class TestMinisite(ImioSmartwebTestCase):
         html = viewlet.render()
         soup = BeautifulSoup(html)
         img = soup.find("img")
-        self.assertEqual(img.get("src"), "http://nohost/plone/logo.png")
+        self.assertEqual(
+            img.get("src"), "http://nohost/plone/++resource++plone-logo.svg"
+        )
         annotations = IAnnotations(self.request)
         del annotations["plone.memoize"]
         view = getMultiAdapter((self.folder, self.request), name="minisite_settings")
@@ -353,13 +372,22 @@ class TestMinisite(ImioSmartwebTestCase):
         view.enable()
         self.assertTrue(viewlet.available())
         attr = {"absolute_url.return_value": "http://www.test.be/folder/minisite"}
-        with patch("plone.api.portal.get", return_value=mock.Mock(**attr)):
+        with patch(
+            "plone.api.portal.get_navigation_root",
+            return_value=mock.Mock(**attr),
+        ):
             self.assertEqual(viewlet.get_hostname(), "test.be")
         attr = {"absolute_url.return_value": "http://test.be/folder/minisite"}
-        with patch("plone.api.portal.get", return_value=mock.Mock(**attr)):
+        with patch(
+            "plone.api.portal.get_navigation_root",
+            return_value=mock.Mock(**attr),
+        ):
             self.assertEqual(viewlet.get_hostname(), "test.be")
         attr = {"absolute_url.return_value": "http://sub.test.be/folder/minisite"}
-        with patch("plone.api.portal.get", return_value=mock.Mock(**attr)):
+        with patch(
+            "plone.api.portal.get_navigation_root",
+            return_value=mock.Mock(**attr),
+        ):
             self.assertEqual(viewlet.get_hostname(), "sub.test.be")
 
     def test_messagesviewlet_in_minisite(self):
@@ -379,8 +407,8 @@ class TestMinisite(ImioSmartwebTestCase):
         self.assertEqual(len(viewlet.getAllMessages()), 1)
 
         view = getMultiAdapter((self.folder, self.request), name="minisite_settings")
-        self.assertTrue(view.available)
-        self.assertFalse(view.enabled)
+        self.assertTrue(view.available())
+        self.assertFalse(view.enabled())
         view.enable()
-        self.assertTrue(view.enabled)
+        self.assertTrue(view.enabled())
         self.assertEqual(len(viewlet.getAllMessages()), 0)
