@@ -149,7 +149,7 @@ class TestPage(ImioSmartwebTestCase):
         getMultiAdapter((page, self.request), name="full_view")()
         bundles = getattr(self.request, "enabled_bundles", [])
         self.assertEqual(len(bundles), 2)
-        self.assertListEqual(bundles, ["spotlightjs", "flexbin"])
+        self.assertListEqual(bundles, ["spotlight", "flexbin"])
 
     def test_js_bundles_with_contact(self):
         page = api.content.create(
@@ -171,14 +171,14 @@ class TestPage(ImioSmartwebTestCase):
         getMultiAdapter((page, self.request), name="full_view")()
         bundles = getattr(self.request, "enabled_bundles", [])
         self.assertEqual(len(bundles), 2)
-        self.assertListEqual(bundles, ["spotlightjs", "flexbin"])
+        self.assertListEqual(bundles, ["spotlight", "flexbin"])
 
         section_contact.gallery_mode = "swiper"
         setattr(self.request, "enabled_bundles", [])
         getMultiAdapter((page, self.request), name="full_view")()
         bundles = getattr(self.request, "enabled_bundles", [])
         self.assertEqual(len(bundles), 1)
-        self.assertListEqual(bundles, ["spotlightjs"])
+        self.assertListEqual(bundles, ["spotlight"])
 
     def test_modification_date(self):
         page = api.content.create(
