@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 
 from freezegun import freeze_time
+from imio.smartweb.core import config
 from imio.smartweb.core.contents.rest.directory.endpoint import DirectoryEndpoint
 from imio.smartweb.core.contents.rest.events.endpoint import EventsEndpoint
+from imio.smartweb.core.contents.rest.events.endpoint import expand_occurences
 from imio.smartweb.core.contents.rest.news.endpoint import NewsEndpoint
 from imio.smartweb.core.testing import IMIO_SMARTWEB_CORE_ACCEPTANCE_TESTING
 from imio.smartweb.core.testing import ImioSmartwebTestCase
@@ -69,7 +71,12 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
         endpoint = DirectoryEndpoint(self.portal, request)
         params = endpoint.get_extra_params([])
         self.assertEqual(
-            params, ['taxonomy_contact_category=("token")', "topics=education"]
+            params,
+            [
+                'taxonomy_contact_category=("token")',
+                "topics=education",
+                "translated_in_en=1",
+            ],
         )
 
         request = TestRequest(
@@ -79,7 +86,12 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
         params = endpoint.get_extra_params([])
         self.assertEqual(
             params,
-            ["topics=education", "metadata_fields=topics", "metadata_fields=category"],
+            [
+                "topics=education",
+                "metadata_fields=topics",
+                "metadata_fields=category",
+                "translated_in_en=1",
+            ],
         )
 
     @requests_mock.Mocker()
@@ -92,7 +104,10 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
         )
         # react additionnal fields request.
         request = TestRequest(
-            form={"taxonomy_contact_category": '("token")', "topics": "education"}
+            form={
+                "taxonomy_contact_category_for_filtering": ("token"),
+                "topics": "education",
+            }
         )
         endpoint = DirectoryEndpoint(rest_directory, request)
         url = endpoint.query_url
@@ -108,8 +123,9 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
             "fullobjects=1&"
             "sort_on=sortable_title&"
             "b_size=20&"
-            'taxonomy_contact_category=("token")&'
-            "topics=education",
+            "taxonomy_contact_category_for_filtering=token&"
+            "topics=education&"
+            "translated_in_en=1",
         )
         m.get(url, text=json.dumps([]))
         call = endpoint()
@@ -120,6 +136,37 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
         self.assertNotIn("b_size=20", url)
         self.assertIn("b_size=30", url)
 
+        json_contact_category_raw_mock = get_json(
+            "resources/json_contact_category_raw_mock.json"
+        )
+        with patch(
+            "imio.smartweb.core.vocabularies.get_wca_token", return_value="kamoulox"
+        ):
+            url = f"{config.DIRECTORY_URL}/@vocabularies/collective.taxonomy.contact_category"
+            m.get(url, text=json.dumps(json_contact_category_raw_mock))
+
+            rest_directory.selected_categories = ["hlsm9bijb1", "9kgcmrj4lu"]
+            url = endpoint.query_url
+            self.assertEqual(
+                url,
+                "http://localhost:8080/Plone/@search?"
+                "selected_entities=396907b3b1b04a97896b12cc792c77f8&"
+                "portal_type=imio.directory.Contact&"
+                "metadata_fields=facilities&"
+                "metadata_fields=taxonomy_contact_category&"
+                "metadata_fields=topics&"
+                "metadata_fields=has_leadimage&"
+                "fullobjects=1&"
+                "sort_on=sortable_title&"
+                "b_size=30&"
+                "taxonomy_contact_category.query=hlsm9bijb1&"
+                "taxonomy_contact_category.query=9kgcmrj4lu&"
+                "taxonomy_contact_category.operator=or&"
+                "taxonomy_contact_category_for_filtering=token&"
+                "topics=education&"
+                "translated_in_en=1",
+            )
+
     @requests_mock.Mocker()
     @freeze_time("2021-11-15")
     def test_call_events(self, m):
@@ -144,7 +191,8 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
             "sort_on=event_dates&"
             "fullobjects=1&"
             "b_size=20&"
-            "event_type=event-driven".format(self.rest_events.selected_agenda),
+            "event_type=event-driven&"
+            "translated_in_en=1".format(self.rest_events.selected_agenda),
         )
         m.get(url, text=json.dumps([]))
         call = endpoint()
@@ -180,6 +228,84 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
             ][0]
             self.assertEqual(patch_selected_agendas, response_selected_agendas)
 
+    @freeze_time("2022-11-10")
+    def test_expand_occurences(self):
+        # test without occurence
+        events = [
+            {
+                "start": "2022-11-13T12:00:00+00:00",
+                "end": "2022-11-13T13:00:00+00:00",
+                "recurrence": None,
+                "open_end": False,
+                "whole_day": False,
+            }
+        ]
+        expanded_events = expand_occurences(events)
+        self.assertEqual(len(expanded_events), 1)
+        events = [
+            {
+                "start": "2022-11-13T12:00:00+00:00",
+                "end": "2022-11-14T13:00:00+00:00",
+                "recurrence": None,
+                "open_end": False,
+                "whole_day": False,
+            }
+        ]
+        expanded_events = expand_occurences(events)
+        self.assertEqual(len(expanded_events), 1)
+
+        # test range start for occurences
+        events = [
+            {
+                "start": "2022-11-01T12:00:00+00:00",
+                "end": "2022-11-01T13:00:00+00:00",
+                "recurrence": "RRULE:FREQ=WEEKLY;COUNT=5",
+                "open_end": False,
+                "whole_day": False,
+            }
+        ]
+        expanded_events = expand_occurences(events)
+        self.assertEqual(len(expanded_events), 3)
+
+        # test occurences data
+        events = [
+            {
+                "start": "2022-11-13T12:00:00+00:00",
+                "end": "2022-11-13T13:00:00+00:00",
+                "recurrence": "RRULE:FREQ=WEEKLY;COUNT=5",
+                "open_end": False,
+                "whole_day": False,
+            }
+        ]
+        expanded_events = expand_occurences(events)
+        self.assertEqual(len(expanded_events), 5)
+        self.assertEqual(expanded_events[-1]["start"], "2022-12-11T12:00:00+00:00")
+        self.assertEqual(expanded_events[-1]["end"], "2022-12-11T13:00:00+00:00")
+        events = [
+            {
+                "start": "2022-11-13T12:00:00+00:00",
+                "end": "2022-11-13T12:00:00+00:00",
+                "recurrence": "RRULE:FREQ=WEEKLY;COUNT=5",
+                "open_end": False,
+                "whole_day": True,
+            }
+        ]
+        expanded_events = expand_occurences(events)
+        self.assertEqual(expanded_events[-1]["start"], "2022-12-11T12:00:00+00:00")
+        self.assertEqual(expanded_events[-1]["end"], "2022-12-12T11:59:59+00:00")
+        events = [
+            {
+                "start": "2022-11-13T00:00:00+00:00",
+                "end": "2022-11-13T23:59:59+00:00",
+                "recurrence": "RRULE:FREQ=WEEKLY;COUNT=5",
+                "open_end": True,
+                "whole_day": True,
+            }
+        ]
+        expanded_events = expand_occurences(events)
+        self.assertEqual(expanded_events[-1]["start"], "2022-12-11T00:00:00+00:00")
+        self.assertEqual(expanded_events[-1]["end"], "2022-12-11T23:59:59+00:00")
+
     @requests_mock.Mocker()
     def test_call_news(self, m):
         endpoint = NewsEndpoint(self.rest_news, self.request)
@@ -197,7 +323,8 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
             "sort_on=effective&"
             "sort_order=descending&"
             "b_size=20&"
-            "fullobjects=1".format(self.rest_news.selected_news_folder),
+            "fullobjects=1&"
+            "translated_in_en=1".format(self.rest_news.selected_news_folder),
         )
         m.get(url, text=json.dumps([]))
         call = endpoint()
